@@ -5,118 +5,7 @@
 
   Contents:     Electronic logbook utility
 
-  $Log$
-  Revision 1.29  2005/08/04 20:26:35  ritt
-  Do not distinguish between invalid user name and invalid password for security reasons
-
-  Revision 1.28  2005/08/04 19:27:58  ritt
-  Implemented encoding=0,1,2
-
-  Revision 1.27  2005/07/25 18:04:12  ritt
-  Applied pointer casting patch from Recai
-
-  Revision 1.26  2005/07/20 19:01:56  ritt
-  Removed 'host:' for HTML/1.0
-
-  Revision 1.25  2005/03/21 16:16:52  ritt
-  Version 2.8.1-1
-
-  Revision 1.24  2005/03/21 16:06:48  ritt
-  Added STRLCPY_DEFINED
-
-  Revision 1.23  2005/01/15 17:05:09  midas
-  Changed comment
-
-  Revision 1.22  2004/11/02 16:46:55  midas
-  Added -H flag for HTML submit
-
-  Revision 1.21  2004/09/18 04:42:46  midas
-  Fixed bug with not displaying inline images
-
-  Revision 1.20  2004/03/28 10:41:05  midas
-  Fixed problem with logbooks containing blanks
-
-  Revision 1.19  2004/03/26 08:28:29  midas
-  Version 2.5.2
-
-  Revision 1.18  2004/03/25 19:47:48  midas
-  Fixed problem with attributes containing spaces
-
-  Revision 1.17  2004/03/14 16:43:29  midas
-  Implemented option 'guest display'
-
-  Revision 1.16  2004/02/19 08:18:31  midas
-  Changed '-p' for email suppress to '-x'
-
-  Revision 1.15  2004/02/17 11:17:03  midas
-  Fixed compiler warnings
-
-  Revision 1.14  2004/02/13 20:58:21  midas
-  Changed email suppression flag from '-s' to '-p'
-
-  Revision 1.13  2004/01/07 11:14:53  midas
-  Changed line length
-
-  Revision 1.12  2004/01/06 13:21:34  midas
-  Changed indent style
-
-  Revision 1.11  2003/11/11 12:31:34  midas
-  Added '-s' flag for email suppression
-
-  Revision 1.10  2003/07/15 12:17:45  midas
-  Removed BOOL
-
-  Revision 1.9  2003/07/15 12:17:13  midas
-  Removed FALSE/TRUE
-
-  Revision 1.8  2003/07/15 12:16:52  midas
-  Removed FALSE/TRUE
-
-  Revision 1.7  2003/07/15 11:19:45  midas
-  Added -e flag, reply now quotes original text
-
-  Revision 1.6  2003/06/25 15:25:13  midas
-  Fixed bug with 'reply_to'
-
-  Revision 1.5  2003/06/05 07:16:36  midas
-  Creat boundary randomly
-
-  Revision 1.4  2003/06/04 14:26:59  midas
-  elog utility can read text from stdin
-
-  Revision 1.3  2003/06/03 13:18:00  midas
-  Fixed bug in base64_encode
-
-  Revision 1.2  2003/03/01 16:07:02  midas
-  Show error if wrong username/password
-
-  Revision 1.1  2003/01/30 14:45:07  midas
-  Moved files to src/ subdirectory
-
-  Revision 1.10  2002/10/14 08:26:26  midas
-  Made attachment size variable
-
-  Revision 1.9  2002/08/02 11:01:34  midas
-  Added -r for replies
-
-  Revision 1.8  2002/07/23 11:31:08  midas
-  Fixed problems with password cookie
-
-  Revision 1.7  2002/07/08 08:39:38  midas
-  Fixed return code
-
-  Revision 1.6  2002/06/12 07:52:41  midas
-  Increased text size
-
-  Revision 1.5  2002/06/11 12:01:45  midas
-  Added -s for subdirectory
-
-  Revision 1.4  2002/02/25 15:28:01  midas
-  Require -l flag, output better error messages
-
-  Revision 1.3  2001/12/21 15:28:51  midas
-  Initial version as separate package, corresponds to V1.3.2
-
+  $Id: elog.c 1668 2006-02-23 14:38:19Z ritt $
 
 \********************************************************************/
 
@@ -300,11 +189,11 @@ Encode the given string in-place by adding %XX escapes
 \********************************************************************/
 {
    unsigned char *pd, *p;
-   char str[NAME_LENGTH];
+   unsigned char str[NAME_LENGTH];
 
    pd = (unsigned char *) str;
    p = (unsigned char *) ps;
-   while (*p && (int) pd < (int) str + 250) {
+   while (*p && pd < str + 250) {
       if (strchr("%&=#?+", *p) || *p > 127) {
          sprintf((char *) pd, "%%%02X", *p);
          pd += 3;
@@ -359,7 +248,7 @@ void add_crlf(char *buffer, int bufsize)
 
       strlcpy(tmpbuf, p, bufsize);
       *(p++) = '\r';
-      strlcpy(p, tmpbuf, bufsize - ((int) p - (int) buffer));
+      strlcpy(p, tmpbuf, bufsize - (p - buffer));
       p++;
    }
 
@@ -1023,7 +912,7 @@ int main(int argc, char *argv[])
    char host_name[256], logbook[32], textfile[256], password[80], subdir[256];
    char *buffer[MAX_ATTACHMENTS], attachment[MAX_ATTACHMENTS][256];
    INT att_size[MAX_ATTACHMENTS];
-   INT i, n, fh, n_att, n_attr, size, port, reply, edit, encoding, suppress;
+   INT i, n, fh, n_att, n_attr, port, reply, edit, encoding, suppress, size;
    char attr_name[MAX_N_ATTR][NAME_LENGTH], attrib[MAX_N_ATTR][NAME_LENGTH];
 
    text[0] = textfile[0] = uname[0] = upwd[0] = suppress = 0;
@@ -1132,11 +1021,11 @@ int main(int argc, char *argv[])
          return 1;
       }
 
-      size = lseek(fh, 0, SEEK_END);
+      size = (INT) lseek(fh, 0, SEEK_END);
       lseek(fh, 0, SEEK_SET);
 
-      if (size > (int) sizeof(text) - 1) {
-         printf("Message file \"%s\" is too long (%d bytes max).\n", textfile, sizeof(text));
+      if (size > (INT) (sizeof(text) - 1)) {
+         printf("Message file \"%s\" is too long (%zd bytes max).\n", textfile, sizeof(text));
          return 1;
       }
 
