@@ -36,7 +36,7 @@
    in the tree and for manipulating nodes, like replacing, adding and
    deleting nodes.
 
-   $Id: mxml.c 36 2005-12-20 07:09:34Z ritt $
+   $Id: mxml.c 45 2006-11-20 08:55:30Z schneebeli_m@PSI.CH $
 
 \********************************************************************/
 
@@ -66,7 +66,9 @@
 #include <ctype.h>
 #include <stdarg.h>
 #include <errno.h>
+#ifndef OS_VXWORKS
 #include <sys/time.h>
+#endif
 #include <time.h>
 
 #endif
@@ -76,6 +78,8 @@
 
 #define XML_INDENT "  "
 
+static int mxml_suppress_date_flag = 0; /* suppress writing date at the top of file. */
+
 /*------------------------------------------------------------------*/
 
 int mxml_write_line(MXML_WRITER *writer, const char *line)
@@ -125,7 +129,8 @@ MXML_WRITER *mxml_open_buffer()
    strcpy(str, ctime(&now));
    str[24] = 0;
    sprintf(line, "<!-- created by MXML on %s -->\n", str);
-   mxml_write_line(writer, line);
+   if (mxml_suppress_date_flag == 0)
+      mxml_write_line(writer, line);
 
    /* initialize stack */
    writer->level = 0;
@@ -136,6 +141,14 @@ MXML_WRITER *mxml_open_buffer()
 
 /*------------------------------------------------------------------*/
 
+void mxml_suppress_date(int suppress)
+ /* suppress writing date at the top of file. */
+{
+   mxml_suppress_date_flag = suppress;
+}
+
+/*------------------------------------------------------------------*/
+
 MXML_WRITER *mxml_open_file(const char *file_name) 
 /* open a file and write XML header */
 {
@@ -163,7 +176,8 @@ MXML_WRITER *mxml_open_file(const char *file_name)
    strcpy(str, ctime(&now));
    str[24] = 0;
    sprintf(line, "<!-- created by MXML on %s -->\n", str);
-   mxml_write_line(writer, line);
+   if (mxml_suppress_date_flag == 0)
+      mxml_write_line(writer, line);
 
    /* initialize stack */
    writer->level = 0;
@@ -270,10 +284,10 @@ void mxml_decode(char *str)
          strcpy(p, p+5);
       }
    }
-   if (str[0] == '\"' && str[strlen(str)-1] == '\"') {
+/*   if (str[0] == '\"' && str[strlen(str)-1] == '\"') {
       strcpy(str, str+1);
       str[strlen(str)-1] = 0;
-   }
+   }*/
 }
 
 /*------------------------------------------------------------------*/
@@ -382,7 +396,7 @@ int mxml_end_element(MXML_WRITER *writer)
 int mxml_write_attribute(MXML_WRITER *writer, const char *name, const char *value)
 /* write an attribute to the currently open XML element */
 {
-   char name_enc[1000], val_enc[1000], line[2000];
+   char name_enc[4000], val_enc[4000], line[8000];
 
    if (!writer->element_is_open)
       return FALSE;
@@ -428,6 +442,22 @@ int mxml_write_value(MXML_WRITER *writer, const char *data)
 
 /*------------------------------------------------------------------*/
 
+int mxml_write_empty_line(MXML_WRITER *writer)
+/* write empty line */
+{
+   if (writer->element_is_open) {
+      mxml_write_line(writer, ">\n");
+      writer->element_is_open = FALSE;
+   }
+
+   if (mxml_write_line(writer, "\n") != 1)
+      return FALSE;
+
+   return TRUE;
+}
+
+/*------------------------------------------------------------------*/
+
 int mxml_write_comment(MXML_WRITER *writer, const char *string)
 /* write a comment to an XML file, enclosed in "<!--" and "-->" */
 {
@@ -526,14 +556,6 @@ PMXML_NODE mxml_add_special_node_at(PMXML_NODE parent, int node_type, char *node
       pchild = parent->child;
       parent->child = (PMXML_NODE)realloc(parent->child, sizeof(MXML_NODE)*(parent->n_children+1));
 
-      if (parent->child != pchild) {
-         /* correct parent pointer for children */
-         for (i=0 ; i<parent->n_children ; i++) {
-            pchild = parent->child+i;
-            for (j=0 ; j<pchild->n_children ; j++)
-               pchild->child[j].parent = pchild;
-         }
-      }
    }
    assert(parent->child);
 
@@ -542,6 +564,13 @@ PMXML_NODE mxml_add_special_node_at(PMXML_NODE parent, int node_type, char *node
       for (i=parent->n_children ; i > index ; i--)
          memcpy(&parent->child[i], &parent->child[i-1], sizeof(MXML_NODE));
 
+   /* correct parent pointer for children */
+   for (i=0 ; i<parent->n_children ; i++) {
+      pchild = parent->child+i;
+      for (j=0 ; j<pchild->n_children ; j++)
+         pchild->child[j].parent = pchild;
+   }
+
    /* initialize new node */
    pnode = &parent->child[index];
    memset(pnode, 0, sizeof(MXML_NODE));
@@ -731,7 +760,7 @@ int mxml_find_nodes1(PMXML_NODE tree, char *xml_path, PMXML_NODE **nodelist, int
    char cond_name[MXML_MAX_CONDITION][256], cond_value[MXML_MAX_CONDITION][256];
    int  cond_type[MXML_MAX_CONDITION];
    int i, j, k, index, num_cond;
-   int cond_satisfied;
+   int cond_satisfied,cond_index;
    size_t len;
 
    p1 = xml_path;
@@ -775,10 +804,14 @@ int mxml_find_nodes1(PMXML_NODE tree, char *xml_path, PMXML_NODE **nodelist, int
             p2 = strchr(p2, ']')+1;
             if ((p3 = strchr(condition, '=')) != NULL) {
 
-               if (condition[0] == '@')
+               if (condition[0] == '@') {
                   cond_type[num_cond] = 1;
+                  strlcpy(cond_name[num_cond], &condition[1], sizeof(cond_name[num_cond]) - 1);
+               }
+               else {
+                  strlcpy(cond_name[num_cond], condition, sizeof(cond_name[num_cond]));
+               }
 
-               strlcpy(cond_name[num_cond], condition, sizeof(cond_name[num_cond]));
                *strchr(cond_name[num_cond], '=') = 0;
                while (cond_name[num_cond][0] && isspace(cond_name[num_cond][strlen(cond_name[num_cond])-1]))
                   cond_name[num_cond][strlen(cond_name[num_cond])-1] = 0;
@@ -808,6 +841,7 @@ int mxml_find_nodes1(PMXML_NODE tree, char *xml_path, PMXML_NODE **nodelist, int
          }
       }
 
+      cond_index = 0;
       for (i=j=0 ; i<pnode->n_children ; i++) {
          if (num_cond) {
             cond_satisfied = 0;
@@ -827,9 +861,13 @@ int mxml_find_nodes1(PMXML_NODE tree, char *xml_path, PMXML_NODE **nodelist, int
                            cond_satisfied++;
                }
             }
-            if (cond_satisfied==num_cond)
-               if (!mxml_add_resultnode(pnode->child+i, p2, nodelist, found))
-                  return 0;
+            if (cond_satisfied==num_cond) {
+               cond_index++;
+               if (index == 0 || cond_index == index) {
+                  if (!mxml_add_resultnode(pnode->child+i, p2, nodelist, found))
+                     return 0;
+               }
+            }
          } else {
             if (strcmp(pnode->child[i].name, node_name) == 0)
                if (index == 0 || ++j == index)
@@ -1995,10 +2033,10 @@ void mxml_debug_tree(PMXML_NODE tree, int level)
 
    for (i=0 ; i<level ; i++)
       printf("  ");
-   printf("Addr: %08X\n", (size_t)tree);
+   printf("Addr: %08zX\n", (size_t)tree);
    for (i=0 ; i<level ; i++)
       printf("  ");
-   printf("Prnt: %08X\n", (size_t)tree->parent);
+   printf("Prnt: %08zX\n", (size_t)tree->parent);
    for (i=0 ; i<level ; i++)
       printf("  ");
    printf("NCld: %d\n", tree->n_children);
