@@ -5,7 +5,7 @@
 
    Contents:     Header file for mxml.c
 
-   $Id: mxml.h 35 2005-11-22 09:48:58Z schneebeli_m $
+   $Id: mxml.h 45 2006-11-20 08:55:30Z schneebeli_m@PSI.CH $
 
 \********************************************************************/
 
@@ -73,15 +73,17 @@ extern "C" {
 #endif
 #endif
 
+void mxml_suppress_date(int suppress);
 MXML_WRITER *mxml_open_file(const char *file_name);
-MXML_WRITER *mxml_open_buffer(void); 
+MXML_WRITER *mxml_open_buffer(void);
 int mxml_set_translate(MXML_WRITER *writer, int flag);
 int mxml_start_element(MXML_WRITER *writer, const char *name);
 int mxml_start_element_noindent(MXML_WRITER *writer, const char *name);
-int mxml_end_element(MXML_WRITER *writer); 
+int mxml_end_element(MXML_WRITER *writer);
 int mxml_write_comment(MXML_WRITER *writer, const char *string);
 int mxml_write_attribute(MXML_WRITER *writer, const char *name, const char *value);
 int mxml_write_value(MXML_WRITER *writer, const char *value);
+int mxml_write_empty_line(MXML_WRITER *writer);
 char *mxml_close_buffer(MXML_WRITER *writer);
 int mxml_close_file(MXML_WRITER *writer);
 
