@@ -5,12 +5,14 @@
 
    Contents:     Header file for strlcpy.c
 
-   $Log: strlcpy.h,v $
-   Revision 1.1  2005/05/09 09:12:06  ritt
-   Initial revision
+   $Id: strlcpy.h 33 2005-10-24 07:56:51Z ritt $
 
 \********************************************************************/
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifndef EXPRT
 #if defined(EXPORT_DLL)
 #define EXPRT __declspec(dllexport)
@@ -21,3 +23,7 @@
 
 size_t EXPRT strlcpy(char *dst, const char *src, size_t size);
 size_t EXPRT strlcat(char *dst, const char *src, size_t size);
+
+#ifdef __cplusplus
+}
+#endif
